OiRA

Help

1. It-Tħejjija
2. Involvi
3. L-Identifikazzjoni + Il-Valutazzjoni
   1. 1 Commercial manned guarding
   2. Ω Riskji miżjuda (minnek).
      1. Ω.1 The entrance floor is often wet
   - Ma saritx żjara
   - Posponiment
   - Riskju mhux preżenti
   - Riskju preżenti
4. Il-Pjan ta' Azzjoni
5. Ir-Rapport
6. Stat 0%

F'każ li għandek riskji identifikati mhux inklużi fl-għodda, dawn tista' żżidhom issa:

Important: Sabiex tevita li tidduplika ir-riskji, nirrakomandawlek li terġa’ iddur il-moduli preċedenti, jekkdan għadek m’għamiltux.

Jekk ma għandekx bżonn iżżid riskji, jekk jogħġbok kompli.

Preċedenti Kompli għall-pjan ta’ azzjoni

Scroll to top
Back

## other-risks.html

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More